References
==========

**Code**: `Github`_ repo

**Paper**: If you use Schema, please consider citing *Schema: metric learning enables interpretable synthesis of heterogeneous single-cell modalities* (http://doi.org/10.1101/834549)

**Project Website**: http://schema.csail.mit.edu



.. _Github: https://github.com/rs239/schema


